ReceivedPacket

Struct ReceivedPacket 

pub struct ReceivedPacket {
    pub data: Box<[u8]>,
}
Available on crate features ble and unstable only.
Represents a received BLE packet.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Fields

data: Box<[u8]>

The data of the received packet.